==> bamboo_1.2.orig.tar.gz: bamboo-1.2/decorators/spartan/style.php <==
body {
	margin: 0px;
	padding: 0px;
	background: #e6e6e6;
	color: #000;
	font-size: 0.9em;
	line-height: 1.5;
	margin-top: 0px;
	margin-left: 0px;
	margin-right: 0px;
}
img { border: 0; }
body, td, th, dd, dt, h1, h2, h3, h4, h5, h6, p, ol, ul, li {
  font-family: sans-serif;
}

p { color: #000; }
pre { color: #000; }
h1 { text-align: center; }
h2 { color: #989894; } 
h4 { font-family: sans-serif; }
dl dt { font-weight: bold; }

p, td, body {
	font-size: 11pt;
}

#content {
	min-height: 350px;
	min-width: 400px;
	max-width: 600px;
	background: white;
	border-left: #000 1px solid;
	border-right: #000 1px solid;
	border-bottom: #000 1px solid;
	padding: 2em;
}

.shade {
  background: #FFF6DD;
  border: solid 1px;
  border-color: #AAA688 #DDD6CC #DDD6CC #AAA688;
  padding: 2px;
}
.code {
  overflow: auto;
}
code {
  font-family: monospace;
}
.title {
   border-bottom: 1px #000 dotted;
}

/*** BEGIN NAVIGATION ***/

#nav {
	margin-top: 4em;
}

#nav ol {
	list-style-type: none;
	margin: 0px;
	padding: 0px;
}

#nav li {
	margin: 0px;
	padding: 0px;
}

div#list {
	margin-top: 2em;
	border-top: #999 1px solid;
}

#nav ol a {
	padding-left: 5px;
}

#nav ol ol a {
	padding-left: 20px;
}

#nav ol ol ol a {
	padding-left: 35px;
}

#nav a {
	display: block;
	border-bottom: #999 1px solid;
	padding: 3px; 
	padding-right: 2em;
}

#nav a:link, #nav a:visited {
	text-decoration: none;
}

#nav a.selected {
	background-color: #ddf;
	font-weight: bold;
}

#nav a:hover {
	background-color: #ccf;
	color: #000;
}

#nav #root {
	min-height: 2em;
}

==> bamboo_1.3.orig.tar.gz: bamboo-1.3/decorators/spartan/style.php <==
/* layout */

body {
	margin: 0;
	padding: 0;
	min-width:800px;
}
img { border: 0; }
#content {
	min-height: 450px;
	width: 600px;
	padding: 2em;
	border-left: #000 1px solid;
	border-right: #000 1px solid;
	border-bottom: #000 1px solid;
	margin-left: 150px;
}
#nav {
	width: 150px;
	float: left;
}

/* style */

body {
	background: #e6e6e6;
	color: #000;
}
img { border: 0; }

p   { color: #000; }
pre { color: #000; }
h1  { text-align: center; }
h2  { color: #989894; } 
dl dt { font-weight: bold; }

#content, td {
	font: small Helvetica, sans-serif;
	line-height: 1.5em;
}
#content {
	background: white;
}

.shade {
  background: #FFF6DD;
  border: solid 1px;
  border-color: #AAA688 #DDD6CC #DDD6CC #AAA688;
  padding: 2px;
}
.code {
  overflow: auto;
}
code {
  font-family: monospace;
}
.title {
   border-bottom: 1px #000 dotted;
}

/* navigation */

#nav {
	margin-top: 4em;
	font: x-small Helvetica, sans-serif;
	min-width: 90px;
}

#nav ol {list-style-type: none; margin: 0; padding: 0;}
#nav li {margin: 0; padding: 0;}
div#list {
	margin-top: 2em;
	border-top: #999 1px solid;
}
#nav ol a {padding-left: 5px;}
#nav ol ol a {padding-left: 20px;}
#nav ol ol ol a {padding-left: 35px;}
#nav a {
	display: block;
	border-bottom: #999 1px solid;
	padding: 3px; 
	padding-right: 2em;
}
#nav a:link, #nav a:visited {
	text-decoration: none;
}
#nav a.selected {
	background-color: #ddf;
	font-weight: bold;
}
#nav a:hover {
	background-color: #ccf;
	color: #000;
}
#nav #root {
	min-height: 2em;
}
